==> frontengine_dev-0.0.64-py3-none-any.whl: frontengine/utils/multi_language/russian.py <==
russian_word_dict = {
    # Menubar
    "menu_bar_language": "Выбор языка",
    "menu_bar_ui_style": "Выбор стиля интерфейса",
    # Language Menubar
    "language_menu_bar_english": "Английский",
    "language_menu_bar_traditional_chinese": "Традиционный китайский",
    "language_menu_bar_simplified_chinese": "Упрощенный китайский",
    "language_menu_bar_germany": "немецкий",
    "language_menu_bar_russian": "русский",
    "language_menu_bar_french": "французский",
    "language_menu_bar_italian": "итальянский",
    "language_menu_bar_please_restart_messagebox": "Перезапустите, чтобы применить изменения",
    # Tab text
    "tab_video_text": "Видео",
    "tab_image_text": "Изображение",
    "tab_web_text": "Веб",
    "tab_gif_text": "GIF и WEBP",
    "tab_sound_text": "Музыка",
    "tab_text_text": "Текст",
    "tab_external_ui": "Внешний UI",
    "tab_control_center_text": "Центр управления",
    "chat_ui_text": "Чат",
    # Messagebox text
    "paint_gif_message_text": "Ошибка в файле GIF или WEBP",
    "paint_image_message_box_text": "Ошибка изображения",
    "sound_effect_message_box_text": "Ошибка музыки",
    "sound_player_message_box_text": "Ошибка музыки",
    "video_player_message_box_text": "Ошибка видео",
    "webview_message_box_text": "Ошибка веб-страницы",
    "cant_find_extend_ui_message_box_text": "UI не найден",
    # Control Center UI
    "control_center_close_all_video": "Закрыть все видео",
    "control_center_close_all_image": "Закрыть все изображения",
    "control_center_close_all_gif": "Закрыть все GIF",
    "control_center_close_all_web": "Закрыть все веб-страницы",
    "control_center_close_all_sound": "Закрыть всю музыку",
    "control_center_close_all_text": "Закрыть весь текст",
    "control_center_scene": "Закрыть сцену",
    "control_center_clear_log_panel": "Очистить лог",
    "chat_scene_close": "Закрыть все чаты",
    "control_center_close_all": "Закрыть все",
    # General
    "Opacity": "Непрозрачность",
    "Speed": "Скорость",
    "Not Ready": "Не готово",
    "Ready": "Готово",
    "Show on all screen": "Показать на всех экранах",
    "Volume": "Громкость",
    "Font size": "Размер шрифта",
    "Play rate": "Скорость воспроизведения",
    "not_prepare": "Не готово",
    "Show on bottom": "Показать внизу всех окон",
    "url": "Ссылка",
    "text": "Текст",
    "ui_path": "Путь UI",
    "position_x": "Координата X",
    "position_y": "Координата Y",
    "seconds": "Секунды",
    "close_delay": "Время исчезновения подписи в секундах",
    "country_code": "Код страны",
    "show_on_which_monitor": "На каком мониторе показать",
    "ok": "ОК",
    "no": "Нет",
    # GIF setting ui
    "gif_setting_ui_choose_file": "Выберите файл GIF или WEBP",
    "gif_setting_ui_play": "Начать воспроизведение GIF или WEBP",
    "gif_setting_message_box": "Пожалуйста, выберите файл GIF или WEBP",
    # Image setting ui
    "image_setting_choose_file": "Выберите изображение",
    "image_setting_ui_play": "Начать воспроизведение изображения",
    "image_setting_message_box": "Пожалуйста, выберите изображение",
    # Sound player setting ui
    "sound_player_setting_choose_wav_file": "Выберите файл wav",
    "sound_player_setting_choose_sound_file": "Пожалуйста, выберите аудиофайл",
    "sound_player_setting_play_wav": "Начать воспроизведение wav",
    "sound_player_setting_play_sound": "Начать воспроизведение аудиофайла",
    "sound_player_setting_message_box_wav": "Пожалуйста, выберите файл wav",
    "sound_player_setting_message_box_sound": "Пожалуйста, выберите аудиофайл",
    # Text setting ui
    "text_setting_start_draw": "Начать рисование текста на экране",
    "text_setting_choose_alignment": "Выберите выравнивание текста",
    "text_setting_alignment_Top": "Сверху",
    # Video setting ui
    "video_setting_choose_file": "Выберите файл видео",
    "video_setting_start_play": "Начать воспроизведение видео",
    "video_setting_message_box": "Пожалуйста, выберите файл видео",
    # Web setting ui
    "web_setting_open_url": "Открыть веб-страницу по URL",
    "web_setting_open_local_file": "Открыть локальную веб-страницу",
    "web_setting_open_enable_input": "Включить ввод",
    # Scene UI
    "tab_scene_text": "Сцена",
    "scene_start": "Начать сцену",
    "scene_table_view_type": "Тип",
    "scene_file_path": "Путь файла",
    "scene_setting_start_scene_button": "Начать сцену",
    "scene_add_image": "Добавить изображение в сцену",
    "scene_add_gif": "Добавить GIF в сцену",
    "scene_add_sound": "Добавить звук в сцену",
    "scene_add_text": "Добавить текст в сцену",
    "scene_add_video": "Добавить видео в сцену",
    "scene_add_web": "Добавить веб-страницу в сцену",
    "scene_url_label": "URL",
    "scene_add_UI": "Добавить UI в сцену",
    "scene_choose_message_box": "Пожалуйста, выберите файл сцены",
    "scene_choose_output_path_message_box": "Пожалуйста, выберите путь вывода файла сцены",
    "scene_output": "Выходной файл сцены",
    "scene_input": "Входной файл сцены",
    "scene_script_clear": "Очистить все скрипты",
    "scene_script": "Сценарий сцены",
    # Chat scene input
    "chat_scene_input_title": "Введите содержание чата",
    "chat_scene_send_chat": "Отправить текст",
    # Chat scene
    "chat_scene_start_button": "Начать чат",
    "chat_scene_new_topic": "Начать новую тему",
    "chat_scene_creative": "Творческий",
    "chat_scene_precise": "Точный",
    "chat_scene_balanced": "Сбалансированный",
    "chat_gpt_exception": "Ошибка GPT, попробуйте снова или начните новую тему",
    "should_we_show_toast": "Показать диалог?",
    # Chat voice input
    "start_chat_voice_input_ui": "Запустить интерфейс голосового ввода",
    "chat_recognizer_voice_button": "Начать запись звука",
    # Image Generation
    "image_generation_tab": "Генерация изображений",
    "start_generate_image": "Начать генерацию изображения",
    "input_error": "Не вводите пустые строки или пробелы",
    "save_generation_image": "Сохранить изображение",
    # Help Menu
    "help_menu_label": "Меню помощи",
    "help_menu_open_issue": "Открыть жалобу",
    "how_to_critical_exit_action": "Как принудительно закрыть",
    "how_to_critical_exit": "Нажмите F12, чтобы срочно закрыть",
    # HowTo Menu
    "doc_menu_label": "Меню документации",
    "doc_menu_open_doc": "Открыть документацию",
}

==> frontengine_dev-0.0.85-py3-none-any.whl: frontengine/utils/multi_language/russian.py <==
russian_word_dict = {
    # Menubar
    "menu_bar_language": "Выбор языка",
    "menu_bar_ui_style": "Выбор стиля интерфейса",
    # Language Menubar
    "language_menu_bar_english": "Английский",
    "language_menu_bar_traditional_chinese": "Традиционный китайский",
    "language_menu_bar_simplified_chinese": "Упрощенный китайский",
    "language_menu_bar_germany": "немецкий",
    "language_menu_bar_russian": "русский",
    "language_menu_bar_french": "французский",
    "language_menu_bar_italian": "итальянский",
    "language_menu_bar_please_restart_messagebox": "Перезапустите, чтобы применить изменения",
    # Tab text
    "tab_video_text": "Видео",
    "tab_image_text": "Изображение",
    "tab_web_text": "Веб",
    "tab_gif_text": "GIF и WEBP",
    "tab_sound_text": "Музыка",
    "tab_text_text": "Текст",
    "tab_external_ui": "Внешний UI",
    "tab_control_center_text": "Центр управления",
    "chat_ui_text": "Чат",
    # Messagebox text
    "paint_gif_message_text": "Ошибка в файле GIF или WEBP",
    "paint_image_message_box_text": "Ошибка изображения",
    "sound_effect_message_box_text": "Ошибка музыки",
    "sound_player_message_box_text": "Ошибка музыки",
    "video_player_message_box_text": "Ошибка видео",
    "webview_message_box_text": "Ошибка веб-страницы",
    "cant_find_extend_ui_message_box_text": "UI не найден",
    # Control Center UI
    "control_center_close_all_video": "Закрыть все видео",
    "control_center_close_all_image": "Закрыть все изображения",
    "control_center_close_all_gif": "Закрыть все GIF",
    "control_center_close_all_web": "Закрыть все веб-страницы",
    "control_center_close_all_sound": "Закрыть всю музыку",
    "control_center_close_all_text": "Закрыть весь текст",
    "control_center_scene": "Закрыть сцену",
    "control_center_clear_log_panel": "Очистить лог",
    "chat_scene_close": "Закрыть все чаты",
    "control_center_close_all": "Закрыть все",
    # General
    "Opacity": "Непрозрачность",
    "Speed": "Скорость",
    "Not Ready": "Не готово",
    "Ready": "Готово",
    "Show on all screen": "Показать на всех экранах",
    "Volume": "Громкость",
    "Font size": "Размер шрифта",
    "Play rate": "Скорость воспроизведения",
    "not_prepare": "Не готово",
    "Show on bottom": "Показать внизу всех окон",
    "url": "Ссылка",
    "text": "Текст",
    "ui_path": "Путь UI",
    "position_x": "Координата X",
    "position_y": "Координата Y",
    "seconds": "Секунды",
    "close_delay": "Время исчезновения подписи в секундах",
    "country_code": "Код страны",
    "show_on_which_monitor": "На каком мониторе показать",
    "ok": "ОК",
    "no": "Нет",
    "fullscreen_checkbox_label": "Полноэкранный режим?",
    # GIF setting ui
    "gif_setting_ui_choose_file": "Выберите файл GIF или WEBP",
    "gif_setting_ui_play": "Начать воспроизведение GIF или WEBP",
    "gif_setting_message_box": "Пожалуйста, выберите файл GIF или WEBP",
    # Image setting ui
    "image_setting_choose_file": "Выберите изображение",
    "image_setting_ui_play": "Начать воспроизведение изображения",
    "image_setting_message_box": "Пожалуйста, выберите изображение",
    # Sound player setting ui
    "sound_player_setting_choose_wav_file": "Выберите файл wav",
    "sound_player_setting_choose_sound_file": "Пожалуйста, выберите аудиофайл",
    "sound_player_setting_play_wav": "Начать воспроизведение wav",
    "sound_player_setting_play_sound": "Начать воспроизведение аудиофайла",
    "sound_player_setting_message_box_wav": "Пожалуйста, выберите файл wav",
    "sound_player_setting_message_box_sound": "Пожалуйста, выберите аудиофайл",
    # Text setting ui
    "text_setting_start_draw": "Начать рисование текста на экране",
    "text_setting_choose_alignment": "Выберите выравнивание текста",
    "text_setting_alignment_Top": "Сверху",
    # Video setting ui
    "video_setting_choose_file": "Выберите файл видео",
    "video_setting_start_play": "Начать воспроизведение видео",
    "video_setting_message_box": "Пожалуйста, выберите файл видео",
    # Web setting ui
    "web_setting_open_url": "Открыть веб-страницу по URL",
    "web_setting_open_local_file": "Открыть локальную веб-страницу",
    "web_setting_open_enable_input": "Включить ввод",
    # Scene UI
    "tab_scene_text": "Сцена",
    "scene_start": "Начать сцену",
    "scene_table_view_type": "Тип",
    "scene_file_path": "Путь файла",
    "scene_setting_start_scene_button": "Начать сцену",
    "scene_add_image": "Добавить изображение в сцену",
    "scene_add_gif": "Добавить GIF в сцену",
    "scene_add_sound": "Добавить звук в сцену",
    "scene_add_text": "Добавить текст в сцену",
    "scene_add_video": "Добавить видео в сцену",
    "scene_add_web": "Добавить веб-страницу в сцену",
    "scene_url_label": "URL",
    "scene_add_UI": "Добавить UI в сцену",
    "scene_choose_message_box": "Пожалуйста, выберите файл сцены",
    "scene_choose_output_path_message_box": "Пожалуйста, выберите путь вывода файла сцены",
    "scene_output": "Выходной файл сцены",
    "scene_input": "Входной файл сцены",
    "scene_script_clear": "Очистить все скрипты",
    "scene_script": "Сценарий сцены",
    # Particle ui
    "tab_particle_text": "Частица",
    "choose_particle_direction": "Выберите направление частицы",
    "particle_setting_ui_play": "Начать воспроизведение частиц",
    "particle_size": "Размер частицы",
    "particle_count": "Количество частиц",
    "particle_speed": "Скорость частицы",
    # Chat scene input
    "chat_scene_input_title": "Введите содержание чата",
    "chat_scene_send_chat": "Отправить текст",
    # Chat scene
    "chat_scene_start_button": "Начать чат",
    "chat_scene_new_topic": "Начать новую тему",
    "chat_scene_creative": "Творческий",
    "chat_scene_precise": "Точный",
    "chat_scene_balanced": "Сбалансированный",
    "chat_gpt_exception": "Ошибка GPT, попробуйте снова или начните новую тему",
    "should_we_show_toast": "Показать диалог?",
    # Chat voice input
    "start_chat_voice_input_ui": "Запустить интерфейс голосового ввода",
    "chat_recognizer_voice_button": "Начать запись звука",
    # Image Generation
    "image_generation_tab": "Генерация изображений",
    "start_generate_image": "Начать генерацию изображения",
    "input_error": "Не вводите пустые строки или пробелы",
    "save_generation_image": "Сохранить изображение",
    # Help Menu
    "help_menu_label": "Меню помощи",
    "help_menu_open_issue": "Открыть жалобу",
    "how_to_critical_exit_action": "Как принудительно закрыть",
    "how_to_critical_exit": "Нажмите F12, чтобы срочно закрыть",
    # HowTo Menu
    "doc_menu_label": "Меню документации",
    "doc_menu_open_doc": "Открыть документацию",
}
